Change Log — docp_core - v1.0.1 Documentation

# Change Log

- 1.0.1 - Project dependencies updated. by j_berendt at 2026-01-24 17:25:53

      Dependencies:
      - The utils4 library has been added to the dependency list in
        pyproject.toml.

      Released: 2026-01-24

- 1.0.0 - Production release for v1.0.0.dev1. by j_berendt at 2026-01-24 17:13:29

      Released: 2026-01-24

- 1.0.0.dev1 - Initial development complete. by j_berendt at 2025-12-11 13:05:20

      ** Development release for docp-* library development. **

      Objects:
      - The Document object is functional and available.

      Utilities:
      - The utilities.py module from the parsers has been moved here.

      Documentation:
      - Complete.

      Test suite:
      - All tests pass successfully with 100% code coverage.

      Released: n/a

- 1.0.0.dev1 - Initial commit. by j_berendt at 2025-12-11 11:29:24